@@ -5,7 +5,7 @@ use warnings;
 use Carp;
 use Cwd 'realpath';
 
-our $VERSION   = '1.3093';
+our $VERSION   = '1.3095';
 our $AUTHORITY = 'SUKRIA';
 
 use Dancer::App;
@@ -52,6 +52,7 @@ our @EXPORT    = qw(
   debug
   del
   dirname
+  info
   error
   engine
   false
@@ -154,6 +155,7 @@ sub halt            { Dancer::SharedData->response->halt(@_);
                       Dancer::Continuation::Halted->new->throw;
                     }
 sub header          { goto &headers }
+sub info            { goto &Dancer::Logger::info }
 sub push_header     { Dancer::SharedData->response->push_header(@_); }
 sub headers         { Dancer::SharedData->response->headers(@_); }
 sub hook            { Dancer::Hook->new(@_) }
@@ -925,17 +927,17 @@ This hook receives as argument a L<Dancer::Error> object.
 
 =item before
 
-This is an alias to C<before>.
+This hook receives one argument, a reference to the subroutine that
+implements the route that is being intercepted by this hook.
 
-This hook receives no arguments.
-
-  before sub {
+  hook before => sub {
+    my $route_handler = shift;
     ...
   };
 
-is equivalent to
+it is equivalent to the deprecated
 
-  hook before => sub {
+  before sub {
     ...
   };
 
@@ -1070,6 +1072,14 @@ can be a Dancer::Exception, or a string, or whatever was used to C<die>.
 
 =back
 
+=head2 info
+
+Logs a message of info level:
+
+    info "This is a info message";
+
+See L<Dancer::Logger> for details on how to configure where log messages go.
+
 =head2 layout
 
 This method is deprecated. Use C<set>:
